# Generated by Django 3.0.8 on 2020-09-02 15:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('quartet_epcis', '0004_auto_20190812_1630'),
    ]

    operations = [
        migrations.AddField(
            model_name='entryevent',
            name='task_name',
            field=models.CharField(blank=True, help_text='The name of the Task that parsed this Entry and Event.', max_length=150, null=True, verbose_name='Task Name'),
        ),
        migrations.AlterField(
            model_name='documentidentification',
            name='multiple_type',
            field=models.BooleanField(default=False, help_text='A flag to indicate that there is more than one type of Document in the instance.', null=True, verbose_name='Multiple Type'),
        ),
    ]



# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Copyright 2020 SerialLab Corp.  All rights reserved.
import re
from gs123.conversion import BarcodeConverter
from quartet_masterdata.db import DBProxy
from gs123.regex import SGTIN_SN_10_13_ALPHA
from rest_framework.filters import SearchFilter
from logging import getLogger

logger = getLogger(__name__)

proxy = DBProxy()

class EntrySearchFilter(SearchFilter):
    """
    Will convert barcodes to URNS for search if one is detected.
    """

    def get_search_terms(self, request):
        terms = super().get_search_terms(request)
        transformed_terms = []
        for term in terms:
            match = SGTIN_SN_10_13_ALPHA.match(term)
            if match:
                try:
                    group_dict = match.groupdict()
                    cpl = proxy.get_company_prefix_length(group_dict['gtin14'])
                    transformed_terms.append(BarcodeConverter(company_prefix_length=cpl,
                                                              barcode_val=term).epc_urn)
                except:
                    logger.debug('Could not convert the barcode submitted %s',
                                 term)
                    transformed_terms.append(term)
            else:
                transformed_terms.append(term)
        return transformed_terms



# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Copyright 2020 SerialLab Corp.  All rights reserved.
from EPCPyYes.core.v1_2 import events, events as yes_events
from quartet_epcis.parsing.business_parser import BusinessEPCISParser as bep
from quartet_capture.rules import RuleContext

class BusinessEPCISParser(bep):
    """
    Same core functionality as the BusinessEPCISParser from the business_parser
    module but can handle the quartet_capture RuleContext and use to store
    additional contextual values in the back end.
    """

    def __init__(self, stream, event_cache_size: int = 1024,
                 recursive_decommission: bool = True,
                 recursive_child_update: bool = False,
                 child_update_from_top: bool = True,
                 rule_context: RuleContext = None):
        super().__init__(stream, event_cache_size, recursive_decommission,
                         recursive_child_update, child_update_from_top)
        self.rule_context = rule_context
        self.counter = 0

    def clear_cache(self):
        """
        Sets the task name on Entry Events.
        :return: None
        """
        if self.rule_context:
            for entry_event in self.entry_event_cache:
                entry_event.task_name = self.rule_context.task_name
        super().clear_cache()

